@@ -1,6 +1,6 @@
 import argparse
 
-from get_service import get_service
+from google_drive_oauth.get_service import get_service
 
 
 def read_file_from_drive(file_id, client_secret_json_filename):
