@@ -1,6 +1,6 @@
 import argparse
 from googleapiclient.http import MediaFileUpload
-from get_service import get_service
+from google_drive_oauth.get_service import get_service
 
 
 def upload_binary_file_to_drive(file_path, file_name, client_secret_json_filename, parent_folder_id=None):
